Index: buffer.h
===================================================================
RCS file: /usr/local/cvsroot/vorbis-tools/ogg123/buffer.h,v
retrieving revision 1.1
diff -u -r1.1 buffer.h
--- buffer.h	2000/12/30 05:44:31	1.1
+++ buffer.h	2001/03/01 02:35:43
@@ -15,6 +15,7 @@
 {
   char status;       /* Status. See STAT_* below. */
   int fds[2];        /* Pipe file descriptors. */
+  int childpid;      /* PID of the writer process. */
   chunk_t *reader;   /* Chunk the reader is busy with */
   chunk_t *writer;   /* Chunk the writer is busy with */
   chunk_t *end;      /* Last chunk in the buffer (for convenience) */
@@ -27,6 +28,7 @@
 
 #define STAT_FLUSH 1
 #define STAT_SHUTDOWN 2
+#define STAT_PLAYING 4
 
 
 #endif /* !defined (__BUFFER_H) */
Index: buffer.c
===================================================================
RCS file: /usr/local/cvsroot/vorbis-tools/ogg123/buffer.c,v
retrieving revision 1.3
diff -u -r1.3 buffer.c
--- buffer.c	2001/01/30 10:42:48	1.3
+++ buffer.c	2001/03/01 02:35:43
@@ -11,6 +11,7 @@
 #include <sys/stat.h>
 #include <sys/time.h>
 #include <unistd.h> /* for fork and pipe*/
+#include <signal.h>
 #include <fcntl.h>
 
 #ifndef DARWIN
@@ -32,6 +33,10 @@
 void writer_main (volatile buf_t *buf, devices_t *d)
 {
   devices_t *d1;
+
+  /* Wait for the reader thread to fill the buffer */
+  raise(SIGSTOP);
+  
   while (! (buf->status & STAT_SHUTDOWN && buf->reader == buf->writer))
     {
       /* Writer just waits on reader to be done with buf_write.
@@ -70,7 +75,6 @@
 
 buf_t *fork_writer (long size, devices_t *d)
 {
-  int childpid;
   buf_t *buf;
 
   /* Get the shared memory segment. */
@@ -111,15 +115,15 @@
   fflush (stdout);
   /* buffer flushes stderr, but stderr is unbuffered (*duh*!) */
   
-  childpid = fork();
+  buf->childpid = fork();
   
-  if (childpid == -1)
+  if (buf->childpid == -1)
     {
       perror ("fork");
       exit (1);
     }
 
-  if (childpid == 0)
+  if (buf->childpid == 0)
     {
       writer_main (buf, d);
       return NULL;
@@ -143,6 +147,13 @@
       /* buffer overflow (yikes! no actually it's a GOOD thing) */
       int ret;
       char t;
+  
+      if(!(buf->status & STAT_PLAYING))
+      {
+        /* Start the writer process */
+        kill(buf->childpid, SIGCONT);
+        buf->status |= STAT_PLAYING;
+      }
       
       tv.tv_sec = 1;
       tv.tv_usec = 0;
@@ -165,6 +176,14 @@
   struct timeval tv;
 
   buf->status |= STAT_SHUTDOWN;
+
+  if(!(buf->status & STAT_PLAYING))
+  {
+    /* Start the writer process */
+    kill(buf->childpid, SIGCONT);
+    buf->status |= STAT_PLAYING;
+  }
+  
   while (buf->status != 0)
     {
       tv.tv_sec = 1;
